@@ -243,8 +243,12 @@ _gnutls_gen_srp_server_kx (gnutls_session_t session, opaque ** data)
    */
 
   data_b = &data_s[1 + pwd_entry->salt.size];
-  if (_gnutls_mpi_print (&data_b[2], &n_b, B) != 0)
-    return GNUTLS_E_MPI_PRINT_FAILED;
+  if (_gnutls_mpi_print (&data_b[2], &n_b, B) != 0) 
+    {
+      gnutls_assert();
+      return GNUTLS_E_MPI_PRINT_FAILED;
+    }
+
   _gnutls_write_uint16 (n_b, data_b);
 
   _gnutls_hard_log ("INT: SRP B[%d]: %s\n", n_b,
@@ -339,8 +343,11 @@ _gnutls_gen_srp_client_kx (gnutls_session_t session, opaque ** data)
   ret = _gnutls_mpi_dprint (&session->key->key, session->key->KEY);
   _gnutls_mpi_release (&S);
 
-  if (ret < 0)
-    return ret;
+  if (ret < 0) 
+    {
+      gnutls_assert();
+      return ret;
+    }
 
   if (_gnutls_mpi_print (NULL, &n_a, A) != 0)
     {
@@ -362,6 +369,7 @@ _gnutls_gen_srp_client_kx (gnutls_session_t session, opaque ** data)
       gnutls_free (*data);
       return GNUTLS_E_MPI_PRINT_FAILED;
     }
+
   _gnutls_hard_log ("INT: SRP A[%d]: %s\n", n_a,
 		    _gnutls_bin2hex (&data_a[2], n_a, buf, sizeof (buf)));
 
@@ -557,7 +565,10 @@ check_g_n (const opaque * g, size_t n_g, const opaque * n, size_t n_n)
 {
 
   if (n_g != 1 || g[0] != srp_generator)
-    return GNUTLS_E_RECEIVED_ILLEGAL_PARAMETER;
+    {
+      gnutls_assert();
+      return GNUTLS_E_RECEIVED_ILLEGAL_PARAMETER;
+    }
 
   if (n_n == sizeof (srp_params_1024) &&
       memcmp (srp_params_1024, n, n_n) == 0)
@@ -577,6 +588,7 @@ check_g_n (const opaque * g, size_t n_g, const opaque * n, size_t n_n)
       return 0;
     }
 
+  gnutls_assert();
   return GNUTLS_E_RECEIVED_ILLEGAL_PARAMETER;
 }
 
