@@ -127,6 +127,8 @@ static const gnutls_error_entry error_algorithms[] = {
   ERROR_ENTRY (N_("Hashing has failed."), GNUTLS_E_HASH_FAILED, 1),
   ERROR_ENTRY (N_("Base64 decoding error."), GNUTLS_E_BASE64_DECODING_ERROR,
 	       1),
+  ERROR_ENTRY (N_("Base64 unexpected header error."), GNUTLS_E_BASE64_UNEXPECTED_HEADER_ERROR,
+	       1),
   ERROR_ENTRY (N_("Base64 encoding error."), GNUTLS_E_BASE64_ENCODING_ERROR,
 	       1),
   ERROR_ENTRY (N_("Parsing error in password file."),
@@ -216,8 +218,8 @@ static const gnutls_error_entry error_algorithms[] = {
 	       GNUTLS_E_X509_UNSUPPORTED_ATTRIBUTE, 1),
   ERROR_ENTRY (N_("The OID is not supported."), GNUTLS_E_X509_UNSUPPORTED_OID,
 	       1),
-  ERROR_ENTRY (N_("The specified algorithm or protocol is unknown."),
-	       GNUTLS_E_UNKNOWN_ALGORITHM, 1),
+  ERROR_ENTRY (N_("The hash algorithm is unknown."),
+	       GNUTLS_E_UNKNOWN_HASH_ALGORITHM, 1),
   ERROR_ENTRY (N_("The PKCS structure's content type is unknown."),
 	       GNUTLS_E_UNKNOWN_PKCS_CONTENT_TYPE, 1),
   ERROR_ENTRY (N_("The PKCS structure's bag type is unknown."),
@@ -238,6 +240,9 @@ static const gnutls_error_entry error_algorithms[] = {
   ERROR_ENTRY (N_("Verifying TLS/IA phase checksum failed"),
 	       GNUTLS_E_IA_VERIFY_FAILED, 1),
 
+  ERROR_ENTRY (N_("The specified algorithm or protocol is unknown."),
+	       GNUTLS_E_UNKNOWN_ALGORITHM, 1),
+
   {NULL, NULL, 0, 0}
 };
 
