@@ -429,7 +429,7 @@ _gnutls_read_client_hello (gnutls_session_t session, opaque * data,
    */
   if (neg_version >= GNUTLS_TLS1)
     {
-      ret = _gnutls_parse_extensions (session, &data[pos], len);	/* len is the rest of the parsed length */
+      ret = _gnutls_parse_extensions (session, EXTENSION_APPLICATION, &data[pos], len);	/* len is the rest of the parsed length */
       if (ret < 0)
 	{
 	  gnutls_assert ();
@@ -444,6 +444,15 @@ _gnutls_read_client_hello (gnutls_session_t session, opaque * data,
       return ret;
     }
   
+  if (neg_version >= GNUTLS_TLS1)
+    {
+      ret = _gnutls_parse_extensions (session, EXTENSION_TLS, &data[pos], len);	/* len is the rest of the parsed length */
+      if (ret < 0)
+	{
+	  gnutls_assert ();
+	  return ret;
+	}
+    }
 
   /* select an appropriate cipher suite
    */
@@ -1535,7 +1544,7 @@ _gnutls_read_server_hello (gnutls_session_t session,
    */
   if (version >= GNUTLS_TLS1)
     {
-      ret = _gnutls_parse_extensions (session, &data[pos], len);	/* len is the rest of the parsed length */
+      ret = _gnutls_parse_extensions (session, EXTENSION_ANY, &data[pos], len);	/* len is the rest of the parsed length */
       if (ret < 0)
 	{
 	  gnutls_assert ();
