@@ -99,8 +99,8 @@
 
 /* defaults for verification functions
  */
-#define DEFAULT_VERIFY_DEPTH 6
-#define DEFAULT_VERIFY_BITS 8200
+#define DEFAULT_VERIFY_DEPTH 32
+#define DEFAULT_VERIFY_BITS 16*1024
 
 #include <gnutls_mem.h>
 
